Learn R Programming

colourspace (version 0.0.1)

color_map: Precomputed colour map for nearest-name lookup

Description

A data frame containing each colour name, hex code, and coordinates in multiple colour spaces for fast nearest-neighbour search.

Usage

color_map

Arguments

Format

A data frame with the following columns:

hex

Lowercase hex code starting with '#'.

name

Colour name (character).

source

Origin of the colour name: "r" or "extended" (see color_names).

lab_l, lab_a, lab_b

CIELAB components.

oklch_l, oklch_c, oklch_h

OKLCH components.

rgb_r, rgb_g, rgb_b

sRGB components (0-255).

hsl_h, hsl_s, hsl_l

HSL components.

Author

Data curated by David Aerne (https://github.com/meodai).