A data frame containing each colour name, hex code, and coordinates in multiple colour spaces for fast nearest-neighbour search.
color_mapA data frame with the following columns:
Lowercase hex code starting with '#'.
Colour name (character).
Origin of the colour name: "r" or "extended"
(see color_names).
CIELAB components.
OKLCH components.
sRGB components (0-255).
HSL components.
Data curated by David Aerne (https://github.com/meodai).